<?php
/*
  KeyClient payment method class
  Credits to Manuel Semprini
  
  Derived from: KeyClient Credit Card Module for Zen Cart 1.3
  Author: Pier Luigi Papeschi, Paolo Micanti
  http://www.selleriaweb.it

  Released under the GNU General Public License
*/

class keyclient {
	var $code, $title, $description, $enabled;
	
	// class constructor
	function keyclient() {
		global $order;
		
		$this->code			= 'keyclient';
		$this->title		= MODULE_PAYMENT_KEYCLIENT_TEXT_TITLE;
		$this->description	= MODULE_PAYMENT_KEYCLIENT_TEXT_DESCRIPTION;
		$this->enabled		= ((MODULE_PAYMENT_KEYCLIENT_STATUS == 'True') ? true : false);
		$this->sort_order	= MODULE_PAYMENT_KEYCLIENT_SORT_ORDER;
		
		if ((int)MODULE_PAYMENT_KEYCLIENT_ORDER_STATUS_ID > 0) {
			$this->order_status = MODULE_PAYMENT_KEYCLIENT_ORDER_STATUS_ID;
		}
		
		if (is_object($order)) $this->update_status();
		
		$this->form_action_url = 'https://ecommerce.cim-italia.it/ecomm/DispatcherServlet';
	}
	
	// class methods
	function update_status() {
		global $order;
		
		if ( ($this->enabled == true) && ((int)MODULE_PAYMENT_KEYCLIENT_ZONE > 0) ) {
			$check_flag = false;
			$check_query = tep_db_query("SELECT zone_id from " . TABLE_ZONES_TO_GEO_ZONES . " WHERE geo_zone_id = '" . MODULE_PAYMENT_KEYCLIENT_ZONE . "' AND zone_country_id = '" . $order->billing['country']['id'] . "' ORDER BY zone_id");
			while ($check = tep_db_fetch_array($check_query)) {
				if ($check['zone_id'] < 1) {
					$check_flag = true;
					break;
				} elseif ($check['zone_id'] == $order->billing['zone_id']) {
					$check_flag = true;
					break;
				}
			}
			
			if ($check_flag == false) {
				$this->enabled = false;
			}
		}
	}
	
	function selection() {
		return array('id' => $this->code,
					'module' => $this->title);
	}
	
	function pre_confirmation_check() {
		return false;
	}
	
	function javascript_validation() {
		return false;
	}
	
	function confirmation() {
		return array('title' => $this->code);
	}
	
	// Build the data and actions to process when the "Submit" button is pressed on the order-confirmation screen.
	// This sends the data to the payment gateway for processing.
	// These are hidden fields on the checkout confirmation page, sent with POST method.
	function process_button() {
		global $order, $customer_id;
		
		$codTrans = $customer_id . '-' . date("Ymd-Hms");
		$currency = 'EUR';
		$amount = intval($order->info['total'] * 100);
		$language_id = 'ITA';
		
		$data_mac = 'codTrans=' . $codTrans . 'divisa=' . $currency . 'importo=' . $amount . MODULE_PAYMENT_KEYCLIENT_SECRETKEY;
		
		$process_button_string =	tep_draw_hidden_field('alias', MODULE_PAYMENT_KEYCLIENT_ALIAS) .
									tep_draw_hidden_field('importo', $amount) .
									tep_draw_hidden_field('divisa', $currency) . 
									tep_draw_hidden_field('codTrans', $codTrans) . 
									tep_draw_hidden_field('email', trim($order->customer['email_address'])) .
									tep_draw_hidden_field('url', tep_href_link(FILENAME_CHECKOUT_PROCESS, '', 'NONSSL')) . 
									tep_draw_hidden_field('url_back', tep_href_link(FILENAME_CHECKOUT_PAYMENT, '', 'NONSSL')) . 
									tep_draw_hidden_field('languageId', $languages_id) .
									tep_draw_hidden_field('mac', urlencode(base64_encode(md5($data_mac))));
		
		return $process_button_string;
	}
	
	function before_process() {
		$str_mac =	"codTrans=" . $_GET['codTrans'] .
					"esito=" . $_GET['esito'] .
					"importo=" . $_GET['importo'] .
					"divisa=" . $_GET['divisa'] .
					"data=" . $_GET['data'] .
					"orario=" . $_GET['orario'] .
					"codAut=" . $_GET['codAut'] .
					MODULE_PAYMENT_KEYCLIENT_SECRETKEY;
		
		$checkMAC = urlencode(base64_encode(md5($str_mac)));
		
		if ( ($_GET['mac'] != $checkMAC) || ($_GET['esito'] != 'OK') ) {
			tep_redirect(tep_href_link(FILENAME_CHECKOUT_PAYMENT, '', 'NONSSL'));
		}
		
		return false;
	}
	
	function after_process() {
		global $insert_id;
		
		$sql =	"INSERT INTO orders_keyclient VALUES (null, '" . $_GET['importo'] .
				"', '" . $_GET['data'] . 
				"', '" . $_GET['divisa'] .
				"', '" . $_GET['session_id'] .
				"', '" . $_GET['codTrans'] .
				"', '" . $_GET['orario'] .
				"', '" . $_GET['esito'] .
				"', '" . $_GET['codAut'] .
				"', '" . $_GET['$BRAND'] .
				"', '" . $_GET['nome'] .
				"', '" . $_GET['cognome'] .
				"', '" . $_GET['email'] .
				"', '" . $_GET['mac'] .
				"', "  . $insert_id .
				")";
		
		tep_db_query($sql);
	}
	
	function get_error() {
		return array('title' => MODULE_PAYMENT_KEYCLIENT_TEXT_ERROR,
					'error' => stripslashes(urldecode($_GET['error'])));
	}
	
	function check() {
		if (!isset($this->_check)) {
			$check_query = tep_db_query("SELECT configuration_value FROM " . TABLE_CONFIGURATION . " WHERE configuration_key = 'MODULE_PAYMENT_KEYCLIENT_STATUS'");
			$this->_check = tep_db_num_rows($check_query);
		}
		return $this->_check;
	}
	
	function install() {
		$create_sql =	"CREATE TABLE IF NOT EXISTS orders_keyclient (
							keyclient_id int(11) NOT NULL auto_increment,
							importo varchar(30),
							data varchar(8),
							divisa char(3),
							session_id varchar(60),
							codTrans varchar(30),
							orario varchar(6),
							esito char(2),
							codAut varchar(6),
							brand varchar(10),
							nome varchar(30),
							cognome varchar(30),
							email varchar(150),
							mac varchar(64),
							orders_id int(11) NOT NULL default '0',
							PRIMARY KEY (keyclient_id)
						)";
		tep_db_query($create_sql);
		
		tep_db_query("INSERT INTO " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) 
					VALUES ('Abilita il modulo KeyClient', 'MODULE_PAYMENT_KEYCLIENT_STATUS', 'True', 'Attivare il sistema di pagamento tramite il gateway bancario KeyClient?', '6', '0', 'tep_cfg_select_option(array(\'True\', \'False\'), ', now())");
		tep_db_query("INSERT INTO " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) 
					VALUES ('Alias', 'MODULE_PAYMENT_KEYCLIENT_ALIAS', 'testing', 'Alias (valore fisso comunicato da KeyClient nella fase di attivazione definitiva).', '6', '0', now())");
		tep_db_query("INSERT INTO " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) 
					VALUES ('Chiave segreta', 'MODULE_PAYMENT_KEYCLIENT_SECRETKEY', 'esempiodicalcolomac', 'Chiave segreta per calcolo MAC (Message Authentication Code).', '6', '0', now())");
		tep_db_query("INSERT INTO " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) 
					VALUES ('Notifica al cliente', 'MODULE_PAYMENT_KEYCLIENT_EMAIL_CUSTOMER', 'False', 'Dovrebbe KeyClient inviare via email una ricevuta al cliente?', '6', '0', 'tep_cfg_select_option(array(\'True\', \'False\'), ', now())");
		tep_db_query("INSERT INTO " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) 
					VALUES ('Ordine di visualizzazione.', 'MODULE_PAYMENT_KEYCLIENT_SORT_ORDER', '0', 'Indicare l\'ordine con il quale questa modalit di pagamento viene proposta all\'utente. 0  il valore visualizzato per primo.', '6', '0', now())");
		tep_db_query("INSERT INTO " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) 
					VALUES ('Zona di pagamento', 'MODULE_PAYMENT_KEYCLIENT_ZONE', '0', 'Se una zona  selezionata, attiva solo questo metodo di pagamento per quella zona.', '6', '2', 'tep_get_zone_class_title', 'tep_cfg_pull_down_zone_classes(', now())");
		tep_db_query("INSERT INTO " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, use_function, date_added) 
					VALUES ('Stato ordine dopo pagamento', 'MODULE_PAYMENT_KEYCLIENT_ORDER_STATUS_ID', '2', 'Definisce quale stato attribuire all\'ordine una volta completato il pagamento.', '6', '0', 'tep_cfg_pull_down_order_statuses(', 'tep_get_order_status_name', now())");
	}
	
	function remove() {
		tep_db_query("DELETE FROM " . TABLE_CONFIGURATION . " WHERE configuration_key IN ('" . implode("', '", $this->keys()) . "')");
	}
	
	function keys() {
		return array(
			'MODULE_PAYMENT_KEYCLIENT_STATUS', 
    		'MODULE_PAYMENT_KEYCLIENT_ALIAS', 
	    	'MODULE_PAYMENT_KEYCLIENT_SECRETKEY', 
	    	'MODULE_PAYMENT_KEYCLIENT_EMAIL_CUSTOMER', 
	    	'MODULE_PAYMENT_KEYCLIENT_ZONE', 
	    	'MODULE_PAYMENT_KEYCLIENT_ORDER_STATUS_ID', 
	    	'MODULE_PAYMENT_KEYCLIENT_SORT_ORDER'
		);
	}
}
?>